==> providence-generator-java-0.3.11-sources.jar: net/morimekta/providence/generator/format/java/shared/EnumMemberFormatter.java <==
/*
 * Copyright 2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.generator.format.java.shared;

import net.morimekta.providence.generator.GeneratorException;
import net.morimekta.providence.reflect.contained.CEnumDescriptor;

import java.util.Collection;
import java.util.LinkedList;

/**
 * Base interface for formatting a providence message class.
 */
public interface EnumMemberFormatter {
    default void appendClassAnnotations(CEnumDescriptor type) throws GeneratorException {}

    default Collection<String> getExtraImplements(CEnumDescriptor type) throws GeneratorException {
        return new LinkedList<>();
    }

    default void appendMethods(CEnumDescriptor type) throws GeneratorException {}

    default void appendExtraProperties(CEnumDescriptor type) throws GeneratorException {}
}

==> providence-generator-java-2.2.1-sources.jar: net/morimekta/providence/generator/format/java/shared/EnumMemberFormatter.java <==
/*
 * Copyright 2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.generator.format.java.shared;

import net.morimekta.providence.generator.GeneratorException;
import net.morimekta.providence.reflect.contained.CEnumDescriptor;

import java.util.ArrayList;
import java.util.Collection;

/**
 * Base interface for formatting a providence message class.
 */
public interface EnumMemberFormatter {
    default void appendClassAnnotations(CEnumDescriptor type) throws GeneratorException {}

    default Collection<String> getExtraImplements(CEnumDescriptor type) throws GeneratorException {
        return new ArrayList<>();
    }

    default void appendMethods(CEnumDescriptor type) throws GeneratorException {}

    default void appendExtraProperties(CEnumDescriptor type) throws GeneratorException {}
}
